;-----------------------------------------------------------
; *** print model info when user clicks on point in plot ***
;-----------------------------------------------------------
PRO POINT_INFO, xwindow, ywindow, dist

  COMMON models, Nmod,Ngas,Nlam,Nincl1,Nincl2,idat1,idat2,idat3,Nobs,Ncont,Nline, $
               modelID, incl, age, Mdust, RinSave, alphaSED, ParaName, ParaVal,$
               lamcont, Fcont, incl1, incl2, lamobs, Fnuobs, beta_abs, $
               linenameobs, Flineobs, sigmaFnu, sigmaFl, bemcont, bemline, $
               LineName, LineFlux

  COMMON plot, xx, yy, NN, N1, N2, sel, wid
  COMMON fits, ID_best,gas_best,incl1_best,incl2_best,chi_best
  COMMON SEDplot, Nplotted,Fmin,Fmax

  ;print, wid, !D.WINDOW
  if (wid NE !D.WINDOW) then begin
    print, "** ERROR: model info only available for most recent plot"
    RETURN
  endif

  ;-------------------------------------------------
  ;--- find datapoint nearest to cursor position ---
  ;-------------------------------------------------

  coords    = CONVERT_COORD(xwindow, ywindow, /DEVICE, /TO_DATA)
  coordsref = CONVERT_COORD(xwindow+100, ywindow+100, /DEVICE, /TO_DATA)
  xdata  = coords(0)
  ydata  = coords(1)
  xref   = coordsref(0)
  yref   = coordsref(1)
  
  i=0L
  best = 1.0e+99
  repeat begin
    xdiff = ABS((xx(i) - xdata)/(xdata - xref))
    ydiff = ABS((yy(i) - ydata)/(ydata - yref))
    diff  = SQRT(xdiff^2 + ydiff^2)
    if (diff LT best) then begin
      best  = diff
      ibest = i
    endif
    i=i+1
  endrep until (i EQ NN)
  ;print, xx(ibest), yy(ibest)

  ;-----------------------------------------------------
  ;--- label selected datapoint and print model info ---
  ;-----------------------------------------------------

  arrowcoords = CONVERT_COORD(xx(ibest), yy(ibest), /DATA, /TO_DEVICE)
  xarrow = arrowcoords(0)
  yarrow = arrowcoords(1)
  ARROW, xarrow+20,yarrow+20,xarrow,yarrow, color=250,hsize=10, $
         hthick=2.0,thick=2.0,/SOLID

  nsel = WHERE(sel EQ 1, count)                    
  selbest = nsel(ibest)                               ;find corresponding model
  if (count NE NN) then print, '*** ERROR in point_info.pro ***

  ;print, count, NN, N1, N2, Nmod, Ngas, Nincl1, Nincl2

  dim = [Nmod,Ngas,Nincl1]
  index = ARRAY_INDICES(dim, selbest, /DIMENSIONS)

  ID = STRING(modelID(index(0),index(1)),FORMAT='(I6.6)')
  XYOUTS, xarrow+20,yarrow+20,STRTRIM(ID,2),/DEVICE,color=250, $
          CHARSIZE=1.5,CHARTHICK=2.0
        
  ;print, ibest, selbest, dim, index
  k1=index(2)
  qbest=9.e+29
  for k=0,Nincl2-1 do begin
    qual=ABS(incl1(k1)-incl2(k))
    if (qual LT qbest) then begin
      qbest=qual
      k2=k
    endif
  endfor
  i=index(0)
  j=index(1)
  ;print,k1,incl1
  ;print,k2,incl2
  sep1='-----------------------------------------------------'
  sep2='====================================================='
  print
  print,sep2
  print," Selected model ID:   ",$
                  STRTRIM(STRING(i+1,FORMAT='(I5.5)'),2)+ $
              "_"+STRTRIM(STRING(j+1),2)
  print," distance [pc]    =   ",STRTRIM(STRING(dist),2)
  print," inclination[deg] =   ",STRTRIM(STRING(incl1(k1)),2)+ $
              "/"+STRTRIM(STRING(incl2(k2)),2)
  print,sep2
  print,"     Mstar [Msun] = ",ParaVal(WHERE(strpos(ParaName,'Mstar')   GE 0),i,j)
  print,"       age [Myr]  = ",age(i,j)
  print,"      Teff [K]    = ",ParaVal(WHERE(strpos(ParaName,'Teff')    GE 0),i,j)
  print,"     Lstar [Lsun] = ",ParaVal(WHERE(strpos(ParaName,'Lstar')   GE 0),i,j)
  print,"       fUV [-]    = ",ParaVal(WHERE(strpos(ParaName,'fUV')     GE 0),i,j)
  print,"      Mgas [Msun] = ",ParaVal(WHERE(strpos(ParaName,'Mgas')    GE 0),i,j)
  print,"     Mdust [Msun] = ",Mdust(i,j)
  print,"  dust/gas [-]    = ",ParaVal(WHERE(strpos(ParaName,'dust/gas')GE 0),i,j)
  print,"       Rin [AU]   = ",RinSave(i,j)
  print,"      Rout [AU]   = ",ParaVal(WHERE(strpos(ParaName,'Rout')    GE 0),i,j)
  print,"   epsilon [-]    = ",ParaVal(WHERE(strpos(ParaName,'epsilon') GE 0),i,j)
  print,"        H0 [AU]   = ",ParaVal(WHERE(strpos(ParaName,'H0')      GE 0),i,j)
  print,"      beta [-]    = ",ParaVal(WHERE(strpos(ParaName,'beta')    GE 0),i,j)
  print,"    settle [-]    = ",ParaVal(WHERE(strpos(ParaName,'settle')  GE 0),i,j)
  print,"      amin [mic]  = ",ParaVal(WHERE(strpos(ParaName,'amin')    GE 0),i,j)
  print,"      amax [mic]  = ",ParaVal(WHERE(strpos(ParaName,'amax')    GE 0),i,j)
  if (WHERE(strpos(ParaName,'apow') GE 0) ne -1) then print,"      apow [-]    = ",ParaVal(WHERE(strpos(ParaName,'apow')    GE 0),i,j)
  print,sep1
  print,format='("   Mass(O) [Msun] =",E12.3,"    <Tg(O)> [K] = ",F8.3)',$
           ParaVal(WHERE(ParaName EQ 'M_O'),i,j),$
           ParaVal(WHERE(ParaName EQ '<Tg_O>'),i,j)
  print,format='("  Mass(C+) [Msun] =",E12.3,"   <Tg(C+)> [K] = ",F8.3)',$
           ParaVal(WHERE(ParaName EQ 'M_C+'),i,j),$
           ParaVal(WHERE(ParaName EQ '<Tg_C+>'),i,j)
  print,format='("  Mass(CO) [Msun] =",E12.3,"   <Tg(CO)> [K] = ",F8.3)',$
           ParaVal(WHERE(ParaName EQ 'M_CO'),i,j),$
           ParaVal(WHERE(ParaName EQ '<Tg_CO>'),i,j)
  ind = WHERE(ParaName EQ "M_H2O", count)
  if (count EQ 1) then begin
    print,format='("  Mass(H2O)[Msun] =",E12.3,"  <Tg(H2O)> [K] = ",F8.3)',$
           ParaVal(WHERE(ParaName EQ 'M_H2O'),i,j),$
           ParaVal(WHERE(ParaName EQ '<Tg_H2O>'),i,j)
  endif else begin                               
    v1 = ParaVal(WHERE(ParaName EQ 'M_oH2O'),i,j)  
    v2 = ParaVal(WHERE(ParaName EQ 'M_pH2O'),i,j)
    v3 = ParaVal(WHERE(ParaName EQ '<Tg_oH2O>'),i,j) 
    v4 = ParaVal(WHERE(ParaName EQ '<Tg_pH2O>'),i,j)
    print,format='("  Mass(H2O)[Msun] =",E12.3,"  <Tg(H2O)> [K] = ",F8.3)',$
                 v1+v2,(v1*v3+v2*v4)/(v1+v2)
  endelse  
  print,sep1
  dfac = (140.0/dist)^2
  ind1 = WHERE(strpos(LineName,"OI_63") GE 0)
  ind2 = WHERE(strpos(LineName,"OI_145") GE 0)
  ind3 = WHERE(strpos(LineName,"CII_157") GE 0)
  ind4 = WHERE(strpos(LineName,"CO_1300") GE 0)
  print,"    OI_63  [W/m2] = ",LineFlux(ind1,i,j,k2)*dfac
  print,"    OI_145 [W/m2] = ",LineFlux(ind2,i,j,k2)*dfac
  print,"   CII_157 [W/m2] = ",LineFlux(ind3,i,j,k2)*dfac
  print,"   CO 2->1 [W/m2] = ",LineFlux(ind4,i,j,k2)*dfac
  
  ; --- add selected model to "best" buffer for SED plotting ---
  
  for k=9,1,-1 do begin
    ID_best(k) = ID_best(k-1)
    gas_best(k) = gas_best(k-1) 
    incl1_best(k)=incl1_best(k-1)
    incl2_best(k)=incl2_best(k-1)
    chi_best(k)=chi_best(k-1)
  endfor

  Nplotted=0 
  ID_best(0)=i
  gas_best(0)=j
  incl1_best(0)=k1
  incl2_best(0)=k2
  chi_best(0)=0.0
  

END
